@@ -50,8 +50,4 @@ def cli(conf, recursive, log, pass_argument):
 		supervisor = Supervisor(settings)
 		supervisor()
 
-##########
-
-if __name__ == '__main__':
-	print("MAIN")
-	cli()
\ No newline at end of file
+##########
\ No newline at end of file
